// Fill out your copyright notice in the Description page of Project Settings.

#pragma once

#include "CoreMinimal.h"
#include "EndlessVendetta/InteractionInterface.h"
#include "GameFramework/Actor.h"
#include "LandingZone.generated.h"

UCLASS()
class ENDLESSVENDETTA_API ALandingZone : public AActor, public IInteractionInterface
{
	GENERATED_BODY()
	
	UPROPERTY(EditAnywhere, Category = "Landing Zone")
	FTransform LZ_ExitTransform;
	UPROPERTY(EditAnywhere, Category = "Landing Zone")
	FTransform LZ_TakeoffTransform;

	// Hides or shows key aesthetic features of LZ's based on if the player is landing or not
	void UpdateAllLandingZones(bool Landing);

	

protected:
	UPROPERTY(EditAnywhere, BlueprintReadOnly, Category = "Landing Zone")
	bool IsHomeBase_LZ = false;

	// Allows player to enter their ship through a LZ
	void Interact() override;
	void InteractPrompt() override;
	
public:	
	// Sets default values for this actor's properties
	ALandingZone();

	// Waypoint will display something along the lines of Press F to Land
	UFUNCTION(BlueprintImplementableEvent)
    void SuggestLandingWidget();
	
	// Ran when a player takes off from any LZ in the world
	UFUNCTION(BlueprintImplementableEvent)
	void ShowWaypoint();
	// Ran when player lands at any LZ in the world
	UFUNCTION(BlueprintImplementableEvent)
	void HideWaypoint();

	// Updates all LZ's, then runs exit ship func on player and passes the exit transform
	void Land();
	// Updates all LZ's, then runs enter ship func on player passing the correct takeoff transform
	void Takeoff();
};
